package Lire::Config::Editor;

use strict;

use vars qw($VERSION %map %pathmap);

use Lire::DataTypes qw(:xml :special);
use Lire::Param;
use Lire::Utils qw(xml_encode tempfile);
use Lire::Config;
use Lire::Config::IniFile;
use Carp;

# iets wat .ini genereert volgens de spec
# iets wat de editor start
# iets wat .ini parst
# iets wat XML schrijft


BEGIN {
    $VERSION = '$Revision: 1.8 $' =~ m!Revision: ([.\d]+)!;
}

sub new {
    my $proto = shift;
    my $class = ref $proto || $proto;
    my %args = @_;
    my $self = bless \%args, $class;

    my $conf = Lire::Config::instance();

    $self->{conf} = $conf;

    $self;
}

sub edit {
    my ($self, $file) = @_;

    my @tmp = tempfile('configXXXXXX', SUFFIX => '.ini');
#$tmp[0] = *STDOUT;
    Lire::Config::IniFile::write_ini_file($self->{conf}, $file, @tmp);
    $self->runeditor(@tmp);
    Lire::Config::IniFile::read_ini_file($self->{conf}, $file, @tmp);
#    $self->{conf}->save_xml($file);
    unlink($tmp[1]);
}

sub program {
    return $_[0]->{program};
}

sub runeditor {
    my ($self, $fh, $file) = @_;
    my $prog = $self->program;
    my $ret = system($prog, $file);
    croak("Couldn\'t start editor: $!")
        if $ret == -1;
    croak("Editor failed.")
        if $ret;
}

package Lire::Config::ViEditor;

use vars qw(@ISA);
use Carp;

BEGIN {
    @ISA = qw(Lire::Config::Editor);
}

sub new {
    my $proto = shift;
    my $class = ref $proto || $proto;
    my $self = $class->SUPER::new(@_);

    $self->{program} = 'vi';
#    $self->{program} = 'true';

    $self;
}

package Lire::Config::VimEditor;

use vars qw(@ISA);
use Carp;

BEGIN {
    @ISA = qw(Lire::Config::Editor);
}

sub new {
    my $proto = shift;
    my $class = ref $proto || $proto;
    my $self = $class->SUPER::new(@_);

    $self->{program} = 'vim';

    $self;
}

package Lire::Config::EmacsEditor;

use vars qw(@ISA);
use Carp;

BEGIN {
    @ISA = qw(Lire::Config::Editor);
}

sub new {
    my $proto = shift;
    my $class = ref $proto || $proto;
    my $self = $class->SUPER::new(@_);

    $self->{program} = 'emacs';

    $self;
}

1;

__END__

=pod

=head1 NAME

Lire::Config::Editor - Interface to invoke an editor on a config file

=head1 DESCRIPTION

Classes in this file support an edit() method which translates the
specified XML config file to a .ini file, runs an editor on it, and
transforms the ini file back into an XML config file.

To implement a new editor class you have three options: either set
$self->{program} to the path of your editor, override $self->program
to return the path of the program or override $self->runeditor to
start the editor yourself.

=head1 VERSION

$Id: Editor.pm,v 1.8 2003/05/05 03:44:40 ubiq Exp $

=head1 COPYRIGHT

Copyright (C) 2003 Stichting LogReport Foundation LogReport@LogReport.org

This file is part of Lire.

Lire is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program (see COPYING); if not, check with
http://www.gnu.org/copyleft/gpl.html or write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.

=head1 AUTHOR

Wessel Dankers <wsl@logreport.org>

=cut


