package tests::ConfigLegacyTest;

use strict;

use base qw/Test::Unit::TestCase/;

use Lire::Config;
use Lire::Config::Build qw/ac_path/;
use Lire::Config::Legacy;
use File::Basename;
use Cwd 'realpath';

sub new {
    my $self = shift->SUPER::new(@_);

    $self->{testsdir} = realpath( dirname( __FILE__ ) );

    return $self;
}

sub set_up {
    my $self = $_[0];

    my $cfg = new Lire::Config::XMLFilesConfig;
    foreach my $dir ( Lire::Config->config_spec_path ) {
        $cfg->del_config_spec_path_dir( $dir );
    }

    foreach my $file ( Lire::Config->config_files ) {
        $cfg->del_config_file( $file );
    }

    $cfg->add_config_spec_path_dir( "$self->{testsdir}/../config-spec" );
    $cfg->init;

    $self->{saved_cfg} = $Lire::Config::SINGLETON;
    $Lire::Config::SINGLETON = $cfg;
}

sub tear_down {
    my $self = $_[0];

    $Lire::Config::SINGLETON = $self->{saved_cfg};
}

sub test_compute_xml_filename {
    my $self = $_[0];

    my %filemap =
      (
       "$ENV{HOME}/.lire/etc/defaults" =>
       "$ENV{HOME}/.lire/config/defaults.xml",
       ac_path( 'sysconfdir', 'PACKAGE' ) . "/defaults.local" =>
       ac_path( 'sysconfdir', 'PACKAGE' ) . "/config/defaults.local.xml",
      );
    my $xml_filename = \&Lire::Config::Legacy::_compute_xml_filename;
    while ( my ( $old, $new ) = each %filemap ) {
        $self->assert_equals( $new, $xml_filename->( $old ));
    }
}

sub test_env2xml_file {
    my $self = $_[0];

    local %ENV;
    my %env = (
               LR_DEBUG => 1,
               LR_KEEP => "",
               LR_LOGGERTAG => 'lire',
               LR_USERLEVEL => 'normal',
              );
    while ( my ( $name, $value ) = each %env ) {
        $ENV{$name} = $value;
    }

    my ($count, $cfg) =
      Lire::Config::Legacy::env2xml_file( "HOME/.lire/etc/defaults" );
    $self->assert_equals( 4, $count );
    $self->assert_not_null( $cfg, "env2xml_file returned undef" );
    $self->assert( UNIVERSAL::isa( $cfg, 'Lire::Config::ConfigFile' ),
                   "env2xml_file() didn't return correct instance: $cfg" );

    $self->assert_equals( 1, $cfg->global->get( 'lr_debug' )->as_value() );
    $self->assert_equals( 'lire',
                          $cfg->global->get( 'lr_logging_tag' )->as_value() );
    $self->assert_equals( 'normal', 
                          $cfg->global->get( 'lr_user_level' )->as_value() );
    my $var = $cfg->global->get( 'lr_keep' )->as_value();
    $self->assert( ! $var, "lr_keep should be false" );
}
1;
