package tests::ReportSubreportTest;

use strict;

use base qw/ Test::Unit::TestCase /;
our ($VERSION)	= '$Revision: 1.1 $' =~ m!Revision: ([.\d]+)!;

use Lire::Report;
use Lire::Report::Subreport;
use Carp;

sub new {
    my $self = shift()->SUPER::new( @_ );

    my $start = time;
    my $end = $start + 86400;
    $self->{report} = new Lire::Report( "test", $start, $end );
    $self;
}

sub set_up {
    my $self = $_[0];
}

sub tear_down {
    my $self = $_[0];
}

sub test_new {
    my $self = $_[0];

    my $subreport = new Lire::Report::Subreport( $self->{report}, "top-dirs" );
    $self->assert_not_null( $subreport, "new() returned undef" );
    $self->assert_equals( $self->{report}, $subreport->{report} );
    $self->assert_equals( $self->{report}->superservice,
                          $subreport->superservice,
                        );
    $self->assert_equals( $self->{report}->timespan_start,
                          $subreport->timespan_start,
                        );
    $self->assert_equals( $self->{report}->timespan_end,
                          $subreport->timespan_end,
                        );
    $self->assert_equals( "top-dirs", $subreport->type );
}

sub test_new_missing {
    my $self = $_[0];

    my $subreport = new_missing Lire::Report::Subreport( $self->{report},
                                                         "top-dirs",
                                                         "error",
                                                       );
    $self->assert_not_null( $subreport, "new_missing() returned undef" );
    $self->assert_equals( $self->{report}, $subreport->{report} );
    $self->assert_equals( $self->{report}->superservice,
                          $subreport->superservice,
                        );
    $self->assert_equals( $self->{report}->timespan_start,
                          $subreport->timespan_start,
                        );
    $self->assert_equals( $self->{report}->timespan_end,
                          $subreport->timespan_end,
                        );
    $self->assert_equals( "top-dirs", $subreport->type );
    $self->assert_equals( "error", $subreport->missing_reason );

}

sub test_delete {
    my $self = $_[0];

    my $subreport = new Lire::Report::Subreport( $self->{report}, "top-dirs" );
    $self->assert_not_null( $subreport, "new() returned undef" );
    $subreport->delete;
    $self->assert_null( $subreport->{report},
                        "reference to report wasn't removed" );
    $self->assert_null( $subreport->{table_info},
                        "reference to table_info wasn't removed" );
}

sub test_missing_delete {
    my $self = $_[0];

    my $subreport = new_missing Lire::Report::Subreport( $self->{report},
                                                         "top-dirs", "error" );
    $self->assert_not_null( $subreport, "new_missing() returned undef" );
    $subreport->delete;
    $self->assert_null( $subreport->{report},
                        "reference to report wasn't removed" );
}

1;
